extensions_kit library
Classes
- AvatarImage
- Create Avatar of all types i,e, square, circle, standard with different sizes.
- ErrorLabel
-
- Collect list of TextField controllers
- Specify our error label using dart streams
- FieldValidator
- Gap
- A widget that takes a fixed amount of space in the direction of its parent.
- ImageSize
- ImageSize is used to change the size of the widget.
- MaxGap
- A widget that takes, at most, an amount of space in a Row, Column, or Flex widget.
- Nil
- A widget which is not in the layout and does nothing. It is useful when you have to return a widget and can't return null.
- Validator
- A Validator.
Enums
- AvatarImageShape
- AvatarImageShape is used to shape the AvatarImage widget.
Mixins
- Ext
- A mixin with additional functionality.
Extensions
- ColorOpacityExtension on Color
- An extension on Color to simplify applying opacity in a version-compatible way.
- ContainerExtensions on Container
-
Extensions to access and apply
Containerproperties. - ContextExtensions on BuildContext
- Extensions for adding additional functionality to the BuildContext.
- DateExtension on DateTime
- Extensions for adding additional functionality to the DateTime.
- DevTools on Object
- DevTools extensions
- DurationExt on num
- Provides conversions from num to Duration
- FontColor on TextStyle
- Adds a Color to the textStyle.
- FontSizes on TextStyle
-
Converts a textStyle to the desired font size
Example usage:
context.textStyles.bodyLarge.size10 - FontStyles on TextStyle
- Converts a textStyle to the desired font style.
- FontWeights on TextStyle
- Converts a textStyle to the desired font weight.
- FutureDuration on Duration
- Convert a Duration into a Future.
- Extensions for navigation on the BuildContext.
- NumberExtensions on num
-
Extensions for adding additional functionality to the
num. - PaddingExtension on Widget
-
Extension for adding
Paddingto a Widget. -
SeparatedIterable
on Iterable<
Widget> - Allows to insert a separator between the items of the iterable.
- StringExtensions on String
- Extensions for adding additional functionality to the String.
- StyledText on T
- Extensions for accessing functionality of the Text widget.
- TextStyles on BuildContext
-
Helper extension that allows to use a text style like:
context.textStyles.bodyLarge - WidgetExtensions on Widget
- Extensions for accessing functionality of the Widget.
Functions
-
padOnly(
{double l = 0, double r = 0, double t = 0, double b = 0}) → EdgeInsets - Creates EdgeInsets with only the given values for left, right, top, and bottom offsets.
-
setHashUrlStrategy(
) → void -
Sets the URL strategy of your web app to using a leading has (
#) instead of paths. -
setPathUrlStrategy(
) → void -
Sets the URL strategy of your web app to using paths instead of a leading
hash (
#).